import React, { PureComponent } from 'react';
import { PrismAsync as SyntaxHighlighter } from 'react-syntax-highlighter';
import { normalizeLanguage } from '../supportedLanguages';
import { applyTheme } from '../themes/themeBuilder';
const LANGUAGE_FALLBACK = 'text';
export default class CodeBlock extends PureComponent {
    constructor() {
        super(...arguments);
        this.handleCopy = (event) => {
            /**
             * We don't want to copy the markup after highlighting, but rather the preformatted text in the selection
             */
            const data = event.nativeEvent.clipboardData;
            if (data) {
                event.preventDefault();
                const selection = window.getSelection();
                if (selection === null) {
                    return;
                }
                const selectedText = selection.toString();
                const document = `<!doctype html><html><head></head><body><pre>${selectedText}</pre></body></html>`;
                data.clearData();
                data.setData('text/html', document);
                data.setData('text/plain', selectedText);
            }
        };
    }
    getLineOpacity(lineNumber) {
        if (!this.props.highlight) {
            return 1;
        }
        const highlight = this.props.highlight
            .split(',')
            .map(num => {
            if (num.indexOf('-') > 0) {
                // We found a line group, e.g. 1-3
                const [from, to] = num
                    .split('-')
                    .map(Number)
                    // Sort by lowest value first, highest value last.
                    .sort((a, b) => a - b);
                return Array(to + 1)
                    .fill(undefined)
                    .map((_, index) => index)
                    .slice(from, to + 1);
            }
            return Number(num);
        })
            .reduce((acc, val) => acc.concat(val), []);
        if (highlight.length === 0) {
            return 1;
        }
        if (highlight.includes(lineNumber)) {
            return 1;
        }
        return 0.3;
    }
    render() {
        const { lineNumberContainerStyle, codeBlockStyle, codeContainerStyle, } = applyTheme(this.props.theme);
        const props = {
            language: normalizeLanguage(this.props.language || LANGUAGE_FALLBACK),
            PreTag: 'span',
            style: codeBlockStyle,
            showLineNumbers: this.props.showLineNumbers,
            codeTagProps: { style: codeContainerStyle },
            lineNumberContainerStyle,
        };
        return (React.createElement(SyntaxHighlighter, Object.assign({}, props, { 
            // Wrap lines is needed to set styles on the line.
            // We use this to set opacity if highlight specific lines.
            wrapLines: this.props.highlight.length > 0, lineNumberStyle: (lineNumber) => ({
                opacity: this.getLineOpacity(lineNumber),
            }), 
            // Types are incorrect.
            // @ts-ignore
            lineProps: lineNumber => ({
                style: {
                    opacity: this.getLineOpacity(lineNumber),
                },
            }) }), this.props.text));
    }
}
CodeBlock.displayName = 'CodeBlock';
CodeBlock.defaultProps = {
    showLineNumbers: true,
    language: LANGUAGE_FALLBACK,
    theme: {},
    highlight: '',
};
//# sourceMappingURL=CodeBlock.js.map