import { PureComponent } from 'react';
import { ThemeProps } from '@atlaskit/theme/types';
import { SupportedLanguages } from '../supportedLanguages';
import { CodeBlockTheme } from '../themes/types';
export interface CodeBlockProps {
    /** The code to be formatted */
    text: string;
    /** The language in which the code is written */
    language?: SupportedLanguages | string;
    /** Indicates whether or not to show line numbers */
    showLineNumbers?: boolean;
    /** A custom theme to be applied, implements the CodeBlockTheme interface */
    theme?: CodeBlockTheme | ThemeProps;
    /**
     * Lines to highlight comma delimited.
     * Example uses:
  
     * - To highlight one line `highlight="3"`
     * - To highlight a group of lines `highlight="1-5"`
     * - To highlight multiple groups `highlight="1-5,7,10,15-20"`
     */
    highlight?: string;
}
export default class CodeBlock extends PureComponent<CodeBlockProps, {}> {
    static displayName: string;
    static defaultProps: {
        showLineNumbers: boolean;
        language: string;
        theme: {};
        highlight: string;
    };
    getLineOpacity(lineNumber: number): 1 | 0.3;
    handleCopy: (event: any) => void;
    render(): JSX.Element;
}
