import { __assign, __extends, __read } from "tslib";
import React, { PureComponent } from 'react';
import { PrismAsync as SyntaxHighlighter } from 'react-syntax-highlighter';
import { normalizeLanguage } from '../supportedLanguages';
import { applyTheme } from '../themes/themeBuilder';
var LANGUAGE_FALLBACK = 'text';
var CodeBlock = /** @class */ (function (_super) {
    __extends(CodeBlock, _super);
    function CodeBlock() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.handleCopy = function (event) {
            /**
             * We don't want to copy the markup after highlighting, but rather the preformatted text in the selection
             */
            var data = event.nativeEvent.clipboardData;
            if (data) {
                event.preventDefault();
                var selection = window.getSelection();
                if (selection === null) {
                    return;
                }
                var selectedText = selection.toString();
                var document_1 = "<!doctype html><html><head></head><body><pre>" + selectedText + "</pre></body></html>";
                data.clearData();
                data.setData('text/html', document_1);
                data.setData('text/plain', selectedText);
            }
        };
        return _this;
    }
    CodeBlock.prototype.getLineOpacity = function (lineNumber) {
        if (!this.props.highlight) {
            return 1;
        }
        var highlight = this.props.highlight
            .split(',')
            .map(function (num) {
            if (num.indexOf('-') > 0) {
                // We found a line group, e.g. 1-3
                var _a = __read(num
                    .split('-')
                    .map(Number)
                    // Sort by lowest value first, highest value last.
                    .sort(function (a, b) { return a - b; }), 2), from = _a[0], to = _a[1];
                return Array(to + 1)
                    .fill(undefined)
                    .map(function (_, index) { return index; })
                    .slice(from, to + 1);
            }
            return Number(num);
        })
            .reduce(function (acc, val) { return acc.concat(val); }, []);
        if (highlight.length === 0) {
            return 1;
        }
        if (highlight.includes(lineNumber)) {
            return 1;
        }
        return 0.3;
    };
    CodeBlock.prototype.render = function () {
        var _this = this;
        var _a = applyTheme(this.props.theme), lineNumberContainerStyle = _a.lineNumberContainerStyle, codeBlockStyle = _a.codeBlockStyle, codeContainerStyle = _a.codeContainerStyle;
        var props = {
            language: normalizeLanguage(this.props.language || LANGUAGE_FALLBACK),
            PreTag: 'span',
            style: codeBlockStyle,
            showLineNumbers: this.props.showLineNumbers,
            codeTagProps: { style: codeContainerStyle },
            lineNumberContainerStyle: lineNumberContainerStyle,
        };
        return (React.createElement(SyntaxHighlighter, __assign({}, props, { 
            // Wrap lines is needed to set styles on the line.
            // We use this to set opacity if highlight specific lines.
            wrapLines: this.props.highlight.length > 0, lineNumberStyle: function (lineNumber) { return ({
                opacity: _this.getLineOpacity(lineNumber),
            }); }, 
            // Types are incorrect.
            // @ts-ignore
            lineProps: function (lineNumber) { return ({
                style: {
                    opacity: _this.getLineOpacity(lineNumber),
                },
            }); } }), this.props.text));
    };
    CodeBlock.displayName = 'CodeBlock';
    CodeBlock.defaultProps = {
        showLineNumbers: true,
        language: LANGUAGE_FALLBACK,
        theme: {},
        highlight: '',
    };
    return CodeBlock;
}(PureComponent));
export default CodeBlock;
//# sourceMappingURL=CodeBlock.js.map